# :coding: utf-8
# :copyright: Copyright (c) 2024 ftrack
import maya.cmds as cmds

from ftrack_utils.paths import get_temp_path

from ftrack_framework_core.plugin import BasePlugin
from ftrack_framework_core.exceptions.plugin import PluginExecutionError


class MayaABCExporterPlugin(BasePlugin):
    name = 'maya_abc_exporter'

    def run(self, store):
        '''
        Export collected_chr_object to ABC
        '''
        # Pick the component name
        component_name = self.options.get('component')

        # Save file to a temp file
        exported_path = get_temp_path(
            filename_extension=".abc"
        )
        # Pick the previously collected object from the store
        collected_chr_object = store['components'][component_name].get('collected_chr_object')
        
        # Pick the start and end frames from the optios of the tool config. The UI might have modify those options.
        start_frame = self.options.get('start_frame', 1)
        end_frame = self.options.get('end_frame', 10)

        try:
            # Export the item to ABC
            cmds.select(collected_chr_object)
            cmds.AbcExport(j=f"-frameRange {start_frame} {end_frame} -root {collected_chr_object} -file {exported_path}")
        except Exception as error:
            raise PluginExecutionError(
                message=f"Couldn't export abc, error:{error}"
            )

        # Sotre the result into the store so can be picked by next plugins
        store['components'][component_name]['exported_path'] = exported_path
